'use client';

import { getSession } from "next-auth/react";
import { useEffect, useState } from "react";
import { useRouter } from "next/navigation";
import { toast } from "react-hot-toast";
import { Session } from "next-auth";
import useConfigChatStore from "@/src/feature/messenger/store/chat_store/useConfigChatStore";

function PauseSession() {
    const [session, setSession] = useState<Session | null>(null);
    const [password, setPassword] = useState("");
    const router = useRouter();
    const user = session?.user;
    const id_chatbot = useConfigChatStore(state => state.idChatbot);
    const selectIdChatbot = id_chatbot

    useEffect(() => {
        getSession().then(session => setSession(session));
    }, []);

    const handleResume = async (e: React.FormEvent) => {
        e.preventDefault();
        
        const payload = { 
            email: user?.login, 
            password,
            id_chatbot: selectIdChatbot
        };
        try {
            const response = await fetch(`${process.env.ASSET_PREFIX}/api/pause-session/validate`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify(payload),
            });

            if (response.ok) {
                router.push('/chat/select'); // Redirige al inicio después de reanudar
                router.refresh(); // Refresca la página para actualizar el estado
            }else{
                toast.success('Contraseña incorrecta');
            }
        } catch (error) {
            toast.error('Error al reanudar la sesión');
        }
    };

    return (
        <div className="min-h-screen bg-gray-100 flex items-center justify-center">
            <div className="bg-white p-8 rounded-lg shadow-lg max-w-md w-full">
                {/* Ícono de pausa */}
                <div className="flex justify-center mb-6">
                    <div className="bg-blue-100 p-3 rounded-full">
                        <svg 
                            className="w-12 h-12 text-blue-600" 
                            fill="none" 
                            stroke="currentColor" 
                            viewBox="0 0 24 24"
                        >
                            <path 
                                strokeLinecap="round" 
                                strokeLinejoin="round" 
                                strokeWidth={2} 
                                d="M10 9v6m4-6v6m7-3a9 9 0 11-18 0 9 9 0 0118 0z" 
                            />
                        </svg>
                    </div>
                </div>

                <h2 className="text-2xl font-bold text-center text-gray-800 mb-2">
                    Sesión en Pausa
                </h2>
                <p className="text-center text-gray-600 mb-6">
                    Bienvenido de vuelta, <span className="font-semibold">{user?.name || 'Usuario'}</span>
                </p>

                <form className="space-y-4" onSubmit={handleResume}>
                    <div>
                        <label 
                            htmlFor="password" 
                            className="block text-sm text-center font-medium text-gray-700 mb-1"
                        >
                            Contraseña
                        </label>
                        <input
                            type="password"
                            id="password"
                            value={password}
                            onChange={(e) => setPassword(e.target.value)}
                            className="w-full px-4 py-2 border border-gray-300 rounded-md focus:ring-2 focus:ring-blue-500 focus:border-blue-500"
                            placeholder="Ingresa tu contraseña"
                        />
                    </div>

                    <button
                        type="submit"
                        className="w-full bg-blue-600 text-white py-2 px-4 rounded-md hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 transition-colors"
                    >
                        Reanudar Sesión
                    </button>
                </form>
            </div>
        </div>
    );
}

export default PauseSession;
